/*******************************************************************************
* File Name: Buzzer_Clock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_Buzzer_Clock_H)
#define CY_CLOCK_Buzzer_Clock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void Buzzer_Clock_StartEx(uint32 alignClkDiv);
#define Buzzer_Clock_Start() \
    Buzzer_Clock_StartEx(Buzzer_Clock__PA_DIV_ID)

#else

void Buzzer_Clock_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void Buzzer_Clock_Stop(void);

void Buzzer_Clock_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 Buzzer_Clock_GetDividerRegister(void);
uint8  Buzzer_Clock_GetFractionalDividerRegister(void);

#define Buzzer_Clock_Enable()                         Buzzer_Clock_Start()
#define Buzzer_Clock_Disable()                        Buzzer_Clock_Stop()
#define Buzzer_Clock_SetDividerRegister(clkDivider, reset)  \
    Buzzer_Clock_SetFractionalDividerRegister((clkDivider), 0u)
#define Buzzer_Clock_SetDivider(clkDivider)           Buzzer_Clock_SetDividerRegister((clkDivider), 1u)
#define Buzzer_Clock_SetDividerValue(clkDivider)      Buzzer_Clock_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define Buzzer_Clock_DIV_ID     Buzzer_Clock__DIV_ID

#define Buzzer_Clock_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define Buzzer_Clock_CTRL_REG   (*(reg32 *)Buzzer_Clock__CTRL_REGISTER)
#define Buzzer_Clock_DIV_REG    (*(reg32 *)Buzzer_Clock__DIV_REGISTER)

#define Buzzer_Clock_CMD_DIV_SHIFT          (0u)
#define Buzzer_Clock_CMD_PA_DIV_SHIFT       (8u)
#define Buzzer_Clock_CMD_DISABLE_SHIFT      (30u)
#define Buzzer_Clock_CMD_ENABLE_SHIFT       (31u)

#define Buzzer_Clock_CMD_DISABLE_MASK       ((uint32)((uint32)1u << Buzzer_Clock_CMD_DISABLE_SHIFT))
#define Buzzer_Clock_CMD_ENABLE_MASK        ((uint32)((uint32)1u << Buzzer_Clock_CMD_ENABLE_SHIFT))

#define Buzzer_Clock_DIV_FRAC_MASK  (0x000000F8u)
#define Buzzer_Clock_DIV_FRAC_SHIFT (3u)
#define Buzzer_Clock_DIV_INT_MASK   (0xFFFFFF00u)
#define Buzzer_Clock_DIV_INT_SHIFT  (8u)

#else 

#define Buzzer_Clock_DIV_REG        (*(reg32 *)Buzzer_Clock__REGISTER)
#define Buzzer_Clock_ENABLE_REG     Buzzer_Clock_DIV_REG
#define Buzzer_Clock_DIV_FRAC_MASK  Buzzer_Clock__FRAC_MASK
#define Buzzer_Clock_DIV_FRAC_SHIFT (16u)
#define Buzzer_Clock_DIV_INT_MASK   Buzzer_Clock__DIVIDER_MASK
#define Buzzer_Clock_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_Buzzer_Clock_H) */

/* [] END OF FILE */
