/*******************************************************************************
* File Name: TEC_ADC_PM.c
* Version 2.50
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TEC_ADC.h"


/***************************************
* Local data allocation
***************************************/

static TEC_ADC_BACKUP_STRUCT  TEC_ADC_backup =
{
    TEC_ADC_DISABLED,
    0u    
};


/*******************************************************************************
* Function Name: TEC_ADC_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void TEC_ADC_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: TEC_ADC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void TEC_ADC_RestoreConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: TEC_ADC_Sleep
********************************************************************************
*
* Summary:
*  Stops the ADC operation and saves the configuration registers and component
*  enable state. Should be called just prior to entering sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  TEC_ADC_backup - modified.
*
*******************************************************************************/
void TEC_ADC_Sleep(void)
{
    /* During deepsleep/ hibernate mode keep SARMUX active, i.e. do not open
    *   all switches (disconnect), to be used for ADFT
    */
    TEC_ADC_backup.dftRegVal = TEC_ADC_SAR_DFT_CTRL_REG & (uint32)~TEC_ADC_ADFT_OVERRIDE;
    TEC_ADC_SAR_DFT_CTRL_REG |= TEC_ADC_ADFT_OVERRIDE;
    if((TEC_ADC_SAR_CTRL_REG  & TEC_ADC_ENABLE) != 0u)
    {
        if((TEC_ADC_SAR_SAMPLE_CTRL_REG & TEC_ADC_CONTINUOUS_EN) != 0u)
        {
            TEC_ADC_backup.enableState = TEC_ADC_ENABLED | TEC_ADC_STARTED;
        }
        else
        {
            TEC_ADC_backup.enableState = TEC_ADC_ENABLED;
        }
        TEC_ADC_StopConvert();
        TEC_ADC_Stop();
        
        /* Disable the SAR internal pump before entering the chip low power mode */
        if((TEC_ADC_SAR_CTRL_REG & TEC_ADC_BOOSTPUMP_EN) != 0u)
        {
            TEC_ADC_SAR_CTRL_REG &= (uint32)~TEC_ADC_BOOSTPUMP_EN;
            TEC_ADC_backup.enableState |= TEC_ADC_BOOSTPUMP_ENABLED;
        }
    }
    else
    {
        TEC_ADC_backup.enableState = TEC_ADC_DISABLED;
    }
}


/*******************************************************************************
* Function Name: TEC_ADC_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component enable state and configuration registers.
*  This should be called just after awaking from sleep mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  TEC_ADC_backup - used.
*
*******************************************************************************/
void TEC_ADC_Wakeup(void)
{
    TEC_ADC_SAR_DFT_CTRL_REG = TEC_ADC_backup.dftRegVal;
    if(TEC_ADC_backup.enableState != TEC_ADC_DISABLED)
    {
        /* Enable the SAR internal pump  */
        if((TEC_ADC_backup.enableState & TEC_ADC_BOOSTPUMP_ENABLED) != 0u)
        {
            TEC_ADC_SAR_CTRL_REG |= TEC_ADC_BOOSTPUMP_EN;
        }
        TEC_ADC_Enable();
        if((TEC_ADC_backup.enableState & TEC_ADC_STARTED) != 0u)
        {
            TEC_ADC_StartConvert();
        }
    }
}
/* [] END OF FILE */
