/**
  ******************************************************************************
  * @file    	adc.h
  * @brief   	Control ADC
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
#ifndef __ADC_H
#define __ADC_H
  
#include "project.h"
#include "ADC.h"
#include  "timebase.h"
#include "states.h"
  

/**
  * @note SDS calls for logging the following values:
  *  •	Timestamp (yyyy-mm-dd,hh:mm:ss.uuu)
  *  •	Hot side temperature (0.1°C)
  *  •	Cool side temperature (0.1°C)		
  *  •	Calculated skin temperature (0.1°C)
  *  •	TEC Current (mA)
  *  •	TEC Control voltage mV)
  *  •	Battery voltage mV)
  *  •	Fan current mA)
  *  •	Calculated COP (0.01)
  */

#define NUM_COEFFICIENTS  34
#define NUM_ADC_TESTS      7
#define ADC_RESOLUTION    4095
  
/**
  Find the battery voltages attached. I’m sure we can go lower on the Red. Shut off seems to be around 6.3 volts.

Yellow: 7.0 Volts
Red: 6.8 Volts
*/
#define LOW_THRESHOLD     7000  //  7.0 in millivolts TODO: make sure the scale of the units lines 
#define CRIT_THRESHOLD    6800  //  6.8 in millivolts 
  
typedef struct  {
  uint16_t  vTemp1;
  uint16_t  vTemp2;
  uint16_t  iFan;
  uint16_t  iTec;
  uint16_t  vBatt;
}adc_sample_t;

typedef struct {
  uint64_t  timestamp;
  uint32_t  tHot;
  uint32_t  tCold;
  uint32_t  tSkin;
  uint16_t  mvTec;
  uint16_t  miTec;
  uint16_t  mvBatt;
  uint16_t  miFan;
  uint16_t  COP;
}log_reading_t;

typedef struct {
  int64_t  adcPoint;
  int32_t  tempPoint;
}adc_conversion_t;

typedef struct {
  int32_t adcPoint;
  int32_t lowConv;
  int32_t hiConv;
}adc_test_t;
 
#define K 1.0
#define rTec  2.9
#define rLiner 3.0
//  TODO: Ryan needs to define these...

uint32_t  read_adc( adc_sample_t * );
uint32_t  convert_adc_results( adc_sample_t *, log_reading_t *);
float  convert_adc_voltage( uint16_t);
float  convert_adc_temperature( uint32_t);
float  fan_current( uint16_t iFan);
float  tec_current( uint16_t iTec);
float  tec_voltage( );
float  batt_voltage( int16_t vBatt);

float  calc_skin_temp( float v0, float tHot, float tCold);

extern  log_reading_t logSample;
extern  adc_sample_t adcSample;

#endif  //  __ADC_C

/* [] END OF FILE */
