/**
  ******************************************************************************
  * @file    	buttons.c
  * @brief   	Control cooling 
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
  
#include  "buttons.h"
#include  "timebase.h"
#include  "states.h"

extern cooling_state_t machineState;

/**
  * Power button processing is described by a state machine diagram in the 
  * SDS. Basic states are:
  *       OFF   - nothing going on until power button is pressed
  *       ^|
  *       |V
  *       IDLE  - waiting for cool button to be pressed
  *       ^|
  *       |V
  *       COOL  - actively cooling the socket
  *       ^|
  *       |V
  *       REFRACTORY - "resting" state for cooling.
  */
/**
  * LEDs and the buzzer get triggered from here as well.
  * OFF -> IDLE   : beep onBeepTime mS, flash green LED t_LEDon mS
  *   (bad result of the power-on self-test yield red-yellow LEDs (orange) and beep errorBeepTime mS
  * IDLE -> COOL  : beep coolBeepTime mS, solid blue LED for t_LEDcool mS
  * IDLE -> OFF   : beep offBeepTime mS, rainbow LED for t_LEDoff mS
  * COOL -> OFF   : beep offBeepTime mS, rainbow LED for t_LEDoff mS
  * COOL -> IDLE  : beep idleBeepTime mS, solid voltage-selected LED for t_LEDon mS
  */

/**
  * @brief  Power button processing
  * @param  Duration of depression
  * @retval 0 if success
  * @note   Power button is used to turn device on and off, plus forces a transition from cooling to idle
  *         T_on, T_off, and abortTime are the time constants
  */
int32_t powerButtonAction( int64_t depressionTime){
  if( depressionTime > t_off){
    processEvent( CE_PowerOff);
  }
  else if( depressionTime > t_on){
    if( ST_OFF == machineState){
      processEvent( CE_PowerOn);
    }
  }
  else if( depressionTime > t_tap){
    switch( getState()){
      //  From any state button tap
  case ST_OFF:
  case ST_IDLE:
  case ST_COOL:
  case ST_REFRACT:
  case ST_ERROR:
  default:
      processEvent( CE_ButtonTap);
      break;
    }
  }
  else{
  }
  return 1;
}


int32_t coolingButtonAction( int64_t depressionTime){
  if( depressionTime > 100){
  }
  else if( depressionTime > 50){
  }
  else{
  }
  return 1;
}
  
/* [] END OF FILE */
