/**
  ******************************************************************************
  * @file    	devices.c
  * @brief   	Manage periodic output devices
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
#include "devices.h"
#include "Buzzer_PWM.h"
#include "timebase.h"

#include "LED_B.h"
#include "LED_G.h"
#include "LED_R.h"

active_counter_t Devices[ NUM_DEVICES];


/**
  * @note Manage three LEDs and one buzzer
  * @note The three LEDs must have solid on and blinking capabilities
  * @note The buzzer only needs "blinking" capabilities, but if we model
  * @note it like the LEDs, only one sort of routine needs to be written.
  */

void  LED_B_ON( void){
  LED_B_Write( 1);
}
void  LED_B_OFF( void){
  LED_B_Write( 0);
}
void  LED_G_ON( void){
  LED_G_Write( 1);
}
void  LED_G_OFF( void){
  LED_G_Write( 0);
}
void  LED_R_ON( void){
  LED_R_Write( 1);
}
void  LED_R_OFF( void){
  LED_R_Write( 0);
}
void  buzzer_on( void){
  Buzzer_PWM_Start();
}
void  buzzer_off( void){
  Buzzer_PWM_Stop();
}
  
  
uint32_t kill_device(   SOCKET_DEVICE devId){
  Devices[ devId].counter_state = DEV_OFF;
  Devices[ devId].stop_time = 0;
  Devices[ devId].pfnOff();
  Devices[ devId].pfnNext = NULL;
  return 0;
}
uint32_t blink_device( SOCKET_DEVICE devId, int32_t onoffInterval, int32_t runtime){
  Devices[ devId].counter_state = DEV_BLINK_ON;
  Devices[ devId].stop_time = now() + runtime;
  Devices[ devId].toggle_time = now() + onoffInterval;
  Devices[ devId].ms_interval_preload = onoffInterval;
  Devices[ devId].pfnOn();
  Devices[ devId].pfnNext = NULL;
  return 0;
}
uint32_t start_device( SOCKET_DEVICE devId, int32_t runtime){
  Devices[ devId].counter_state = DEV_ON;
  Devices[ devId].stop_time = now() + runtime;
  Devices[ devId].pfnOn();
  Devices[ devId].pfnNext = NULL;
  return 0;
}
uint32_t start_device_chain( SOCKET_DEVICE devId, int32_t runtime, void (* Next)){
  Devices[ devId].counter_state = DEV_ON;
  Devices[ devId].stop_time = now() + runtime;
  Devices[ devId].pfnOn();
  Devices[ devId].pfnNext = Next;
  return 0;
}
uint32_t wait_device(  SOCKET_DEVICE devId){
  while( Devices[ devId].stop_time);
  return 0;
}
/* [] END OF FILE */
