/**
  ******************************************************************************
  * @file    	devices.h
  * @brief   	Manage periodic output devices
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
#ifndef __DEVICES_H
#define __DEVICES_H
#include "project.h"


//  Defines for button hold times come from the SRS
#define t_off             5000            //  5  seconds
#define t_on              2000            //  2  seconds
#define t_coolbegin       2000            //  2  seconds
#define t_tap             500             //  0.5 seconds (e.g. momentary)
#define t_abort           2000            //  2  seconds
#define t_idle            1000 * 60 * 20  //  20 minutes
#define t_cool            1000 * 60 * 20  //  20 minutes
#define t_ref             1000 * 60 * 5   //  5  minutes
#define t_visible         3000            //  3  seconds

//  Defines for state durations
#define T_idle            1000 * 60 * 20  //  20 minutes  - turn off if idle times out
#define T_cooling         1000 * 60 * 20  //  20 minutes  - switch to refractory if T_cooling times out
#define T_refractory      1000 * 60 * 5   //  5 minutes   - switch to cooling if T_refractory times out

//  Defines for beeper durations
#define t_BEEPidle        500     //  500 mS
#define t_BEEPcool        500     //  500 mS
#define t_BEEPoff         500     //  500 mS
#define t_BEEPon          500     //  500 mS
#define t_BEEPvcrit       1000    //  1 second
#define t_BEEPcheck       500     //  500 mS
#define t_BEEPerror       2000    //  2 seconds

int64_t idleTime, abortTime, powerOnTime, powerOffTime, visibleTime, refractoryTime;
int64_t idleBeepTime, coolBeepTime, offBeepTime, onBeepTime, vcritBeepTime, checkBeepTime, errorBeepTime;


/**
  * @note We have a buzzer and three LEDs at this point...
  */
#define NUM_DEVICES 4 
  
typedef enum {
  DEV_BUZZER = 0,
  DEV_LED_BLUE = 1,
  DEV_LED_RED = 2,
  DEV_LED_GREEN = 3
}SOCKET_DEVICE;

typedef enum{
  DEV_ON = 0,
  DEV_OFF = 1,
  DEV_BLINK_ON = 2,
  DEV_BLINK_OFF = 3,
  DEV_CONTINUOUS = 4
}DEVICE_STATE;
  
void  LED_B_ON( void);
void  LED_B_OFF( void);
void  LED_G_ON( void);
void  LED_G_OFF( void);
void  LED_R_ON( void);
void  LED_R_OFF( void);
void  buzzer_on( void);
void  buzzer_off( void);

uint32_t kill_device(   SOCKET_DEVICE devId);
uint32_t blink_device( SOCKET_DEVICE devId, int32_t onOffIntervale, int32_t runtime);
uint32_t start_device( SOCKET_DEVICE devId, int32_t runtime);
uint32_t start_device_chain( SOCKET_DEVICE devId, int32_t runtime, void (* pfnNext));
uint32_t wait_device(  SOCKET_DEVICE devId);

/* [] END OF FILE */
#endif  //  __DEVICES_H