/**
  ******************************************************************************
  * @file    	i2c.h
  * @brief   	Control I2C
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
  
#ifndef __I2C_H
#define __I2C_H
#include  "project.h"
#include  "I2CM.h"

#define   TRANSFER_ERROR    1
#define   TRANSFER_CMPLT    0
#define   I2C_DELAY         10  //  Ordinarily limit I2C timeout to 10mS
#define   I2C_FOREVER       0   //  Unlimited I2C timeout
  
#define   DUMMY_BYTE 0xFF

  
/* Start and end of packet markers */
#define PACKET_SOP           (0x01UL)
#define PACKET_EOP           (0x17UL)

/* Packet positions */
#define PACKET_SOP_POS       (0UL)
#define PACKET_STS_POS       (1UL)
#define PACKET_EOP_POS       (4UL)

  
/* Command valid status */
#define STS_CMD_DONE         (0x00UL)
#define STS_CMD_FAIL         (0xFFUL)
  
  
uint32_t i2c_read_registers( uint8_t slaveAddress, uint8_t regAddr, uint8_t *rdData, uint32_t count);
uint32_t i2c_write_registers( uint8_t slaveAddress, uint8_t regAddr, uint8_t *wrData, uint32_t count);
uint32_t i2c_write_prefix( uint8_t slaveAddress, uint8_t regAddr);
//uint32_t i2c_write_fram( uint8_t slaveAddress, uint8_t *command, uint32_t count);
uint32_t i2c_query_fram( uint8_t slaveAddress, uint8_t *command, uint32_t count);
uint32_t i2c_read_fram( uint8_t slaveAddress, uint8_t *reply, uint32_t count);

uint32_t i2c_read_memory( uint8_t slaveAddress, uint32_t memAddress, uint8_t *rdData, uint32_t count);
uint32_t i2c_write_memory(uint8_t slaveAddress, uint32_t memAddress, uint8_t *wrData, uint32_t count);
  
uint32_t i2c_query_bridge( uint8_t slaveAddress, uint8_t *wrData, uint32_t count);
uint32_t i2c_read_bridge( uint8_t slaveAddress, uint8_t *rdData, uint32_t count);
uint32_t i2c_write_bridge( uint8_t slaveAddress, uint8_t *wrData, uint32_t count);
  
#endif  //  __I2C_H

/* [] END OF FILE */
