/**
  ******************************************************************************
  * @file    	keyboard.h
  * @brief   	Manages two input buttons
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
  
#ifndef __KEYBOARD_H
#define __KEYBOARD_H
  
#include "project.h"
#include "devices.h"

#define NUM_BUTTONS 2

/**
	*	@brief	Button data includes current state, debounce period, and
  *         pointers to read and action functions.
	*/
typedef	struct{
	int64_t debounceStart;            //  When the pin is declared depressed
  int64_t depressDuration;          //  How long was the pin depressed?
  int32_t (* pAction)(int64_t);     //  ptr to action function
	uint8_t	lastRead;                 //  last pin state
	uint8_t (* pRead)(void);          //  ptr to read function
}button_t;

/**
  * @note - pointers to action and read functions for button_t table
  */
typedef struct{
  int32_t (* pAction)(int64_t);
  uint8_t (* pRead)(void);
}button_functions_t;

int32_t debounce_button( button_t *b);
int32_t process_keyboard( void);
int32_t init_keyboard();




/* [] END OF FILE */
#endif  //  __KEYBOARD_H