/**
  ******************************************************************************
  * @file    	main.c
  * @brief   	Cooling Socket Main Loop
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
/**
  * @note   Increased heap size from default 0x80 to 0x800 (factor of16) as I was getting heap failure interrupts.
  */
#include "project.h"
#include  "timebase.h"
#include  "keyboard.h"
#include  "rtc.h"
#include  "fram.h"
#include  "adc.h"
#include  "logging.h"
#include  "uart.h"
#include  "algorithm.h"
#include  "devices.h"

int32_t  init_pwm( void);

uint32_t  mychar;
uint8_t command;
uint32_t status;

uint64_t    pollTime = 0;
uint64_t    waitTime = 0;

#define RUN_UART
#define RUN_RTC
#define RUN_TIMER
#define RUN_FRAM
#define RUN_ADC
#define RUN_I2C
#define RUN_LOGGING

//#define RUN_LOGGING_FIXUP


rtc_time_t writeTime;
rtc_time_t localTime;

#define LOOP_CONTROL  1 //  controls the do{ }while(LOOP_CONTROL); flow

int main(void)
{
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
  CYASSERT( 8 == sizeof( logvars_t));
  CYASSERT( 24 == sizeof( sysvars_t));

  Timer_Start();
  I2CM_Start();
  I2CM_SCB_IRQ_Enable();
  TEC_ADC_Start();
  TEC_ADC_Init();
  CyGlobalIntEnable;
  init_timebase();
  //suspend_uart();
  awake_uart();
  
  
#if defined( RUN_RTC)
  
  writeTime.hund = 0;
  writeTime.secs = 0;
  writeTime.mins = 30;
  writeTime.hrs = 11;
  writeTime.date = 2;
  writeTime.month = 7;
  writeTime.year = 18;
  /** 
    * Read RTC for testing, then reprogram
    * This is all just test code anyway
    */
  rtc_read_clock( RTC_ADDR, &localTime);
  rtc_write_clock( RTC_ADDR, &writeTime);
  
#endif//  RUN_RTC
  
#if 0
  awake_uart();
  UART1_UartPutString("Cooling Socket 2127\r\n");
  waitTime = now() + 10000;
  while( waitTime > now());
  suspend_uart();
  UART1_UartPutString("Ought not see this...Cooling Socket 2127\r\n");
  waitTime = now() + 10000;
  while( waitTime > now());
  awake_uart();
  UART1_UartPutString("Did you see Cooling Socket 2127?\r\n");
  waitTime = now() + 10000;
  while( waitTime > now());
  
//  suspend_uart();
#endif
  
  init_keyboard();
  init_pwm();
  init_fram();
  
#if defined( RUN_LOGGING_FIXUP)
  /*************************************************************
  */
  //  TODO: This is a fixup for testing
  //        Always erase the first FRAM block and
  //        zero the log variables
  //
  fram_erase_block( FRAM_ADDR, 0);  
  logVars.activeLogPage = 0;  
  logVars.currentPageIndex = 0;
  rtc_write_logvars( RTC_ADDR, &logVars);

  log_init();
  /*************************************************************
  */
#endif

#if 0
  start_device( DEV_LED_RED, 1000);
  start_device( DEV_LED_GREEN, 1000);
  
  blink_device( DEV_LED_BLUE, 500, 5000);
  blink_device( DEV_LED_RED, 250, 10000);
  blink_device( DEV_LED_GREEN, 100, 7500);
  blink_device( DEV_BUZZER, 50, 200);
#endif

/**
  * Begin main loop
  */

  do{
    timebase_tick();
    process_keyboard();
    
    
/**
  * @note test the energy equations
  */
  Q0TestIterator();
  
# if 0    
#if defined( RUN_UART)    
  do{
    mychar = UART1_UartGetChar();
  }while( !mychar);
  if( mychar){      //  Something to look at...
    UART1_UartPutChar( mychar);
  }
#endif  //  RUN_UART
#endif  //  0

#if 1
/**
  * Looking at the RTC
  */
uint8_t fRdBuffer[ 100];  //  TODO: This is test code  
  rtc_get_trickle( RTC_ADDR, fRdBuffer); 
  rtc_set_trickle( RTC_ADDR, 0xA6);   //  Enables the trickle charger
//  TODO: Watch the trickle charger  
//  rtc_get_trickle( RTC_ADDR, fRdBuffer);
//  rtc_set_trickle( RTC_ADDR, 0x00); //  Disables the trickle charger
  
#endif
  


/**
  * @note Winbond tech support say the programming sequence
  *     (not entirely intuitive in my humble opinion)
  *   1) disable write protections in Register A
  *   2) enable FRAM write
  *   3) push data across to the buffer
  *   4) Execute the program operation
  *   5) disable FRAM write
  *   6) enable write protection
  */



  
  //  To avoid working too hard and spending too much energy, poll about 
  //  once a second. This will be replaced with a sleep routine TODO:
  if( now() > pollTime){  
    pollTime = now() + ONE_SECOND;  //  Next is in 1 second
    /**
      * Read ADC channels
      */
    status = read_adc( &adcSample);
  }
/**
  * End of the line
  */
  }while( LOOP_CONTROL);
  /**
    * Look out - it's a trap
    */
  for(;;);
} //  main()

/**
  * @brief  Initialize the PWM driving the TEC
  * @param  None
  * @retval 0
  * @note   PWM period is 100. Drive compare value to 99 to get to low power into the TEC.
  */
int32_t  init_pwm( void){
  TEC_PWM_Init();
  TEC_PWM_WritePeriod( 100);
  TEC_PWM_WriteCompare( 99);    //  Start off with low power
  return 0;
}
/* [] END OF FILE */
