/**
  ******************************************************************************
  * @file    	states.h
  * @brief   	State machine declarations
  *	@author		John Griswold
  *
  ******************************************************************************
  *
  *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
#ifndef __STATES_H  
#define __STATES_H

#include "project.h"
#include "logging.h"
#include "rtc.h"
#include "devices.h"
  
extern  rtc_time_t localTime;
  
/** 
  * @note   Enumeration constants for the cooling state machine
  *       ST_OFF - machine is turned off
  *       ST_IDLE - machine is turned on, waiting for someone to press the cool button
  *       ST_COOL - actively cooling the socket - power applied to TEC
  *       ST_REFRACT - not active cooling - this is the "rest" period
  *       ST_ERROR - some major error has occured, so we'll gripe a bit and shut down
  *       ST_PASSIVE - Passively cooling - we are still in the cooling state, but 
  *                     the TEC is not powered - we're waiting for the skin temp 
  *                     to rise above the threshold
  */
typedef enum{
  ST_OFF = 0,
  ST_IDLE = 1,
  ST_COOL = 2,
  ST_REFRACT = 3,
  ST_ERROR = 4,
  ST_PASSIVE = 5,
}cooling_state_t;

typedef enum{
  CE_PowerOn  = 0,    //  OFF pressed > T_power_on
  CE_PowerOff = 1,    //  OFF pressed > T_power_off
  CE_CoolOn   = 2,    //  COOL pressed > T_cool
  CE_CoolOff  = 3,    //  OFF pressed > T_abort
  CE_Refract  = 4,    //  Time in Refractory state exceeded limit, switch to Cool
  CE_Cool     = 5,    //  Time in active cooling state exceeded limit, switch to Refractory
  CE_IdleTimeout = 6, //  Time in IDLE exceeded limit, power off
  CE_V_Low       = 7, //  Battery level has dropped below 15%
  CE_V_Critical  = 8, //  Battery level has dropped below 5%
  CE_ButtonTap   = 9, //  User has tapped either button
  
}cooling_event_t;

cooling_state_t getState( void);
void setState( cooling_state_t nextState);
cooling_state_t processEvent( cooling_event_t);
uint32_t processOff( void);
void processInit( void);
void blue_led( void);
void red_led( void);
void green_led( void);

#endif  //  __STATES_H

  /* [] END OF FILE */
