/**
  ******************************************************************************
  * @file    	timebase.h
  * @brief   	Maintain time base variables and counters
  *	@author		John Griswold
  *
  ******************************************************************************
  *
 *
  * COPYRIGHT(c) 2018 Vivonics, Inc.
  *
  */
#ifndef __TIMEBASE_H  
#define __TIMEBASE_H  
#include "project.h"
#include "devices.h"

#define ONE_SECOND  1000  //  one thousand mS == 1 second
  
typedef struct {
  int64_t         stop_time;      //  How much time left?
  DEVICE_STATE    counter_state;  //  Blinking?
  int64_t         toggle_time;    //  When to toggle
  int32_t         ms_interval_preload;  //  period of toggle
  void (* pfnOn)(void);           //  Function to turn device on
  void (* pfnOff)(void);          //  Function to turn device off
  void (* pfnNext)(void);         //  Function to do after completion
}active_counter_t;

int32_t init_timebase( void);
int32_t timebase_tick( void);
uint64_t now( void);

extern int16_t logcounter;
extern int16_t logflag;


/* [] END OF FILE */
#endif  //  __TIMEBASE_H